zeit
    * ``auth_token`` Specify your api token


.. note::
   
   Vercel provider requires a token to access its API.
   You can generate one for your account on the following URL:
   https://vercel.com/account/tokens

